@@ -1,5 +1,5 @@
 package Gherkin::Line;
-$Gherkin::Line::VERSION = '30.0.4';
+$Gherkin::Line::VERSION = '30.1.0';
 use strict;
 use warnings;
 
@@ -121,7 +121,7 @@ sub table_cells {
         $stripped_cell =~ s/\s+$//;
         $stripped_cell =~ s/(\\\\|\\\||\\n)/$unescape_map{$1}/g;
         push(
-            @$cells,
+            @{$cells},
             {
                 column => $col + $self->indent + $cell_indent,
                 text   => $stripped_cell
